magneticalc.Options_Menu.Options_Menu

# ``magneticalc`.`Options_Menu`.`Options_Menu``

class documentation

`class Options_Menu(QMenu):`

Constructor: `Options_Menu(gui)`

View In Hierarchy

Options_Menu class.

Method | `__init__` | Undocumented
Method | `on_backend_changed` | Gets called when the backend changed.
Method | `update` | Updates the menu.
Instance Variable | `backend_actions` | Undocumented
Instance Variable | `gui` | Undocumented
Instance Variable | `options_backend_group` | Undocumented

def __init__(self, gui: `GUI`):

Undocumented

def on_backend_changed(self, backend_type: `int`):

Gets called when the backend changed.

Parameters
backend_type: `int` | Backend type

def update(self):

Updates the menu.

backend_actions: `dict` =

Undocumented

gui =

Undocumented

options_backend_group =

Undocumented